﻿################################################################################
## Initialization
################################################################################

init offset = -1


################################################################################
## Styles
################################################################################

style default:
    properties gui.text_properties()
    language gui.language

style input:
    properties gui.text_properties("input", accent=True)
    adjust_spacing False

style hyperlink_text:
    properties gui.text_properties("hyperlink", accent=True)
    hover_underline True

style gui_text:
    properties gui.text_properties("interface")


style button:
    properties gui.button_properties("button")

style button_text is gui_text:
    properties gui.text_properties("button")
    yalign 0.5


style label_text is gui_text:
    properties gui.text_properties("label", accent=True)

style prompt_text is gui_text:
    properties gui.text_properties("prompt")


style bar:
    ysize gui.bar_size
    left_bar Frame("gui/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    xsize gui.bar_size
    top_bar Frame("gui/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    ysize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    xsize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    ysize gui.slider_size
    base_bar Frame("gui/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/slider/horizontal_[prefix_]thumb.png"
    thumb_offset 13
    left_gutter 13
    right_gutter 13

style vslider:
    xsize gui.slider_size
    base_bar Frame("gui/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/slider/vertical_[prefix_]thumb.png"


style frame:
    padding gui.frame_borders.padding
    background Frame("gui/frame.png", gui.frame_borders, tile=gui.frame_tile)



################################################################################
## In-game screens
################################################################################


## Say screen ##################################################################
##
## The say screen is used to display dialogue to the player. It takes two
## parameters, who and what, which are the name of the speaking character and
## the text to be displayed, respectively. (The who parameter can be None if no
## name is given.)
##
## This screen must create a text displayable with id "what", as Ren'Py uses
## this to manage text display. It can also create displayables with id "who"
## and id "window" to apply style properties.
##
## https://www.renpy.org/doc/html/screen_special.html#say

screen say(who, what):
    style_prefix "say"

    window:
        id "window"

        if who is not None:

            window:
                id "namebox"
                style "namebox"
                text who id "who"

        text what id "what"


    ## If there's a side image, display it above the text. Do not display on the
    ## phone variant - there's no room.
    if not renpy.variant("small"):
        add SideImage() xalign 0.0 yalign 1.0


## Make the namebox available for styling through the Character object.
init python:
    config.character_id_prefixes.append('namebox')

style window is default
style say_label is default
style say_dialogue is default
style say_thought is say_dialogue

style namebox is default
style namebox_label is say_label


style window:
    xalign 0.5
    xfill True
    yalign gui.textbox_yalign
    ysize gui.textbox_height

    background Image("gui/textbox.png", xalign=0.5, yalign=1.0)

style namebox:
    xpos gui.name_xpos
    xanchor gui.name_xalign
    xsize gui.namebox_width
    ypos gui.name_ypos
    ysize gui.namebox_height

    background Frame("gui/namebox.png", gui.namebox_borders, tile=gui.namebox_tile, xalign=gui.name_xalign)
    padding gui.namebox_borders.padding

style say_label:
    properties gui.text_properties("name", accent=True)
    xalign gui.name_xalign
    yalign 0.5

style say_dialogue:
    properties gui.text_properties("dialogue")

    xpos gui.dialogue_xpos
    xsize gui.dialogue_width
    ypos gui.dialogue_ypos

    line_overlap_split gui.dialogue_text_line_overlap_split


## Input screen ################################################################
##
## This screen is used to display renpy.input. The prompt parameter is used to
## pass a text prompt in.
##
## This screen must create an input displayable with id "input" to accept the
## various input parameters.
##
## https://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):
    style_prefix "input"

    window:

        vbox:
            xalign gui.dialogue_text_xalign
            xpos gui.dialogue_xpos
            xsize gui.dialogue_width
            ypos gui.dialogue_ypos

            text prompt style "input_prompt"
            input id "input"

style input_prompt is default

style input_prompt:
    xalign gui.dialogue_text_xalign
    properties gui.text_properties("input_prompt")

style input:
    xalign gui.dialogue_text_xalign
    xmaximum gui.dialogue_width


## Choice screen ###############################################################
##
## This screen is used to display the in-game choices presented by the menu
## statement. The one parameter, items, is a list of objects, each with caption
## and action fields.
##
## https://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):
    style_prefix "choice"

    vbox:
        if swapchoicepos:
            xalign .9
        else:
            xalign 0.1
        for i in items:
            textbutton i.caption action i.action at mmtransform


## When this is true, menu captions will be spoken by the narrator. When false,
## menu captions will be displayed as empty buttons.
define config.narrator_menu = True


style choice_vbox is vbox
style choice_button is button
style choice_button_text is button_text

style choice_vbox:
    yalign .3

    spacing gui.choice_spacing

style choice_button is default:
    properties gui.button_properties("choice_button")
    activate_sound "music/choice.wav"
    idle_background Solid("#5595")
    hover_background Solid("#BBF3")

style choice_button_text is default:
    properties gui.button_text_properties("choice_button")


## Quick Menu screen ###########################################################
##
## The quick menu is displayed in-game to provide easy access to the out-of-game
## menus.

screen quick_menu():

    ## Ensure this appears on top of other screens.
    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 1.0
            yalign 1.0

            textbutton _("Rewind") action [Rollback(), SensitiveIf(timepowers)]
            textbutton _("Save Points") action [ShowMenu('load'), SensitiveIf(timepowers)]
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Fast Forward") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Menu") action ShowMenu('history')
            #textbutton _("Save") action ShowMenu('save')
            #textbutton _("Options") action ShowMenu('preferences')
            textbutton _("Reset") action MainMenu()


## This code ensures that the quick_menu screen is displayed in-game, whenever
## the player has not explicitly hidden the interface.
init python:
    config.overlay_screens.append("quick_menu")

default quick_menu = True

style quick_button is default
style quick_button_text is button_text

style quick_button:
    properties gui.button_properties("quick_button")

style quick_button_text:
    properties gui.button_text_properties("quick_button")


################################################################################
## Main and Game Menu Screens
################################################################################

## Navigation screen ###########################################################
##
## This screen is included in the main and game menus, and provides navigation
## to other menus, and to start the game.

screen navigation():

    vbox:
        style_prefix "navigation"

        xpos gui.navigation_xpos
        yalign 0.5

        spacing gui.navigation_spacing

        textbutton _("Return") action Return()
        textbutton _("Options") action ShowMenu("preferences")

        #if main_menu:
            #textbutton _("Start") action Start()

        #if not main_menu:
        #    textbutton _("History") action ShowMenu("history")

            #textbutton _("Save") action ShowMenu("save")

        if not persistent.theend and not persistent.promise:
            if not main_menu:
                textbutton _("Save") action [ShowMenu("save"), SensitiveIf(timepowers)]
            textbutton _("Warp") action [ShowMenu("load"), SensitiveIf(timepowers)]

        if persistent.metspace:
            textbutton _("Memories") action ShowMenu("memories")

        #textbutton _("Load") action ShowMenu("load")


        #if _in_replay:

        #    textbutton _("End Replay") action EndReplay(confirm=True)

        if not main_menu:

            textbutton _("Reset") action MainMenu()

        textbutton _("Credits") action ShowMenu("about")

        if renpy.variant("pc"):

            ## Help isn't necessary or relevant to mobile devices.
            textbutton _("How to Play") action ShowMenu("help")

            ## The quit button is banned on iOS and unnecessary on Android.
            textbutton _("Quit") action Quit(confirm=not main_menu)


style navigation_button is gui_button
style navigation_button_text is gui_button_text

style navigation_button:
    size_group "navigation"
    properties gui.button_properties("navigation_button")
    idle_background Solid("#3365")
    hover_background Solid("#BBF3")
    xpadding 12
    yminimum 60
    #activate_sound "music/choice2.wav"

style navigation_button_text:
    properties gui.button_text_properties("navigation_button")
    xalign .5


## Main Menu screen ############################################################
##
## Used to display the main menu when Ren'Py starts.
##
## https://www.renpy.org/doc/html/screen_special.html#main-menu

init -2:
    $ void = False
    $ smooched = False
    $ timepowers = True

screen main_menu():

    ## This ensures that any other menu screen is replaced.
    tag menu

    style_prefix "main_menu"

    if persistent.allclear:
        add "clear bg"
    elif persistent.nilending:
        add "black"
    elif persistent.spaceending:
        add "white"
    else:
        add "mm bg"
    text _("her tears were my light") size 40 xalign .1 yalign .2 outlines [(2,"#000",0,0)] at titletransform
    text _("by NomnomNami") size 30 xalign .25 yalign .9 outlines [(2,"#000",0,0)] at titledissolve

    frame:
        style_group "mm"
        background None
        xalign .9
        yalign .9

        has vbox
        spacing gui.navigation_spacing

        if not persistent.theend:
            textbutton _("Start") action Start() activate_sound "music/start.wav" at mmtransform
            if not persistent.promise:
                textbutton _("Continue") action ShowMenu("load") at mmtransform
        else:
            textbutton _("Restart") action Start("reset") at mmtransform
        textbutton _("Options") action ShowMenu("preferences") at mmtransform
        if persistent.metspace:
            textbutton _("Memories") action ShowMenu("memories") at mmtransform
        if renpy.variant("pc"):
            textbutton _("How to Play") action ShowMenu("help") at mmtransform
            textbutton _("Quit") action Quit(confirm=False) at mmtransform

    if renpy.variant("touch") and persistent.clearmemory:
        imagebutton auto "gui/button/gal_%s.png" action Start("gallery") align (.98,.04)
        vbox:
            align (.02, .96)
            imagebutton auto "gui/button/ostlink_%s.png" action OpenURL("https://lydianchord.bandcamp.com/album/her-tears-were-my-light-soundtrack")
            imagebutton auto "gui/button/mygames_%s.png" action OpenURL("https://nomnomnami.carrd.co/")


style main_menu_frame is empty
style main_menu_vbox is vbox
style main_menu_text is gui_text
style main_menu_title is main_menu_text
style main_menu_version is main_menu_text

style main_menu_frame:
    xsize 280
    yfill True

    background "gui/overlay/main_menu.png"

style main_menu_text:
    properties gui.text_properties("main_menu")

style main_menu_title:
    properties gui.text_properties("title")

style main_menu_version:
    properties gui.text_properties("version")

style mm_button is navigation_button:
    size_group "mm"
    activate_sound "music/choice2.wav"
style mm_button_text is navigation_button_text

transform slowappear:
    alpha 0
    pause 2
    easeout 2.0 alpha .4
screen exitgallery():
    imagebutton idle "gui/button/exitgal_idle.png" action MainMenu(confirm=False) align (.99,.02) at slowappear

## Game Menu screen ############################################################
##
## This lays out the basic common structure of a game menu screen. It's called
## with the screen title, and displays the background, title, and navigation.
##
## The scroll parameter can be None, or one of "viewport" or "vpgrid". When
## this screen is intended to be used with one or more children, which are
## transcluded (placed) inside it.

screen game_menu(title, scroll=None, yinitial=0.0):

    style_prefix "game_menu"

    if void:
        add "black"
    elif smooched:
        add "white"
    elif persistent.nilending:
        add "black"
    elif persistent.spaceending:
        add "white"
    else:
        add "gamemenu bg"

    #if main_menu:
    #    add gui.main_menu_background
    #else:
    #    add gui.game_menu_background

    frame:
        style "game_menu_outer_frame"

        hbox:

            ## Reserve space for the navigation section.
            frame:
                style "game_menu_navigation_frame"

            frame:
                style "game_menu_content_frame"

                if scroll == "viewport":

                    viewport:
                        yinitial yinitial
                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        vbox:
                            transclude

                elif scroll == "vpgrid":

                    vpgrid:
                        cols 1
                        yinitial yinitial

                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        transclude

                else:

                    transclude

    use navigation

    #label title

    if main_menu:
        key "game_menu" action ShowMenu("main_menu")


style game_menu_outer_frame is empty
style game_menu_navigation_frame is empty
style game_menu_content_frame is empty
style game_menu_viewport is gui_viewport
style game_menu_side is gui_side
style game_menu_scrollbar is gui_vscrollbar

style game_menu_label is gui_label
style game_menu_label_text is gui_label_text

style return_button is navigation_button
style return_button_text is navigation_button_text

style game_menu_outer_frame:
    bottom_padding 30
    top_padding 120

    background None#"gui/overlay/game_menu.png"

style game_menu_navigation_frame:
    xsize 300#280
    yfill True

style game_menu_content_frame:
    left_margin 60#40
    right_margin 20
    top_margin 10

style game_menu_viewport:
    xsize 920

style game_menu_vscrollbar:
    unscrollable gui.unscrollable

style game_menu_side:
    spacing 10

style game_menu_label:
    xpos 50
    ysize 120

style game_menu_label_text:
    size gui.title_text_size
    color gui.accent_color
    yalign 0.5
    outlines [(2,"#000",0,0)]
    bold True

style return_button:
    xpos gui.navigation_xpos
    yalign 1.0
    yoffset -30


## About screen ################################################################
##
## This screen gives credit and copyright information about the game and Ren'Py.
##
## There's nothing special about this screen, and hence it also serves as an
## example of how to make a custom screen.

screen about():

    tag menu

    ## This use statement includes the game_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the game_menu
    ## screen.
    use game_menu(_("Credits"), scroll="viewport"):

        style_prefix "about"

        frame:
            has vbox
            imagebutton idle "gui/patreon ad.png" action OpenURL("https://www.patreon.com/nomnomnami") xalign .5 focus_mask None
            label _("[config.name!t] - version [config.version!t]\n")
            vpgrid:
                xysize (800,240)#(800,380)
                cols 1
                yinitial 0
                scrollbars "vertical"
                mousewheel True
                draggable True
                pagekeys True
                side_yfill True
                yoffset -20

                frame:
                    background None
                    has vbox
                    text _("Story + Art by {a=https://nomnomnami.itch.io/}NomnomNami{/a}")
                    text _("Music by {a=https://twitter.com/LydianChord}Alex Huang{/a}")
                    text _("Cosmic Backgrounds by Emmit")
                    if preferences.language is not None:
                        null
                        hbox:
                            text _("Translation: ")
                            if preferences.language=="es":
                                text "HunterTraducciones\nJosé Luis Castillo del Águila"
                            elif preferences.language=="fr":
                                text "LaChouette"
                            elif preferences.language=="kor":
                                text "KyleHeren"
                            elif preferences.language=="german":
                                text "Lisa Petermann\nChristian Paul"
                            elif preferences.language=="ptpt":
                                text "Raquel Espada"
                            elif preferences.language=="italian":
                                text "bri (gabriella longobardi)"
                            elif preferences.language=="pl":
                                text "Dominika Klag"
                            elif preferences.language=="rus":
                                text "tinenmi (Tuna Std.), River"
                            elif preferences.language=="chs":
                                text "HomYvan"
                            elif preferences.language=="cht":
                                text "HomYvan, LydianChord   校對：Sikv"
                            elif preferences.language=="vn":
                                text "minhvipkk"
                            elif preferences.language=="th":
                                text "ProtoFriend"
                            elif preferences.language=="jp":
                                text "Yuki Yoshida"

                    null height 12
                    text _("Made with {a=https://www.renpy.org/}Ren'Py{/a} {size=-5}[renpy.version_only].\n\n[renpy.license!t]")

## This is redefined in options.rpy to add text to the about screen.
define gui.about = ""

style about_label is gui_label
style about_label_text is gui_label_text
style about_text is gui_text
style about_vpgrid:
    xfill True
    xsize 760

style about_label_text:
    size gui.label_text_size
    color "#fff"

style about_frame:
    background Solid("#3365")


## Load and Save screens #######################################################
##
## These screens are responsible for letting the player save the game and load
## it again. Since they share nearly everything in common, both are implemented
## in terms of a third screen, file_slots.
##
## https://www.renpy.org/doc/html/screen_special.html#save https://
## www.renpy.org/doc/html/screen_special.html#load

screen save():

    tag menu

    use file_slots(_("Save"))


screen load():

    tag menu

    use file_slots(_("Load"))

#screen file_picker():
screen file_slots(title):

    use game_menu(title):

        frame:
            style "file_picker_frame"
            has vbox
            label _("Save Points") text_color "#FFF"

            # Display a grid of file slots.
            grid gui.file_slot_cols gui.file_slot_rows:
                transpose True
                xfill True
                xsize 700
                xalign .5
                style_group "file_picker"
                spacing 2

                for i in range(gui.file_slot_cols * gui.file_slot_rows):

                    $ slot = i + 1

                    button:
                        action FileAction(slot)
                        activate_sound "music/fileaction.wav"
                        #xfill True

                        hbox:
                            spacing gui.slot_spacing
                            add FileScreenshot(slot) xalign 0.5

                            vbox:
                                text FileTime(slot, format=_("{#file_time}%B %d, %H:%M"), empty=_("Empty Slot.")):
                                    style "slot_time_text"

                                #text FileSaveName(slot):
                                #    style "slot_name_text"
                                #text "[file_name]. [file_time!t]"

                        key "save_delete" action FileDelete(slot)

            label _("*This game autosaves; using save points is completely optional.") text_color "#FFF"

style file_picker_frame is menu_frame:
    background Solid("#3365")
    xalign .3
    yalign .5
    xfill True
    xsize 700
style file_picker_nav_button: #is small_button:
    hover_background Solid("#FFF4")
#style file_picker_nav_button_text: #is small_button_text
style file_picker_button: #is large_button:
    background Solid("#3365")
    hover_background Solid("#FFF4")
    insensitive_background Solid("#FFF1")
    ysize 100
    padding (20,20)
style file_picker_button_text:
    idle_outlines [(0,None,0,0)]
style file_picker_text: #is large_button_text:
    color "#FFF"
    selected_color "#8BEBFE"
    hover_color "#FFEEAE"


style slot_button is gui_button
style slot_button_text is gui_button_text
style slot_time_text is slot_button_text
style slot_name_text is slot_button_text

style slot_button:
    properties gui.button_properties("slot_button")

style slot_button_text:
    properties gui.button_text_properties("slot_button")


## Preferences screen ##########################################################
##
## The preferences screen allows the player to configure the game to better suit
## themselves.
##
## https://www.renpy.org/doc/html/screen_special.html#preferences


screen preferences():

    tag menu

    use game_menu(_("Options"), scroll="viewport"):

        frame:
            background None
            padding (0,0)
            has hbox
            vbox:
                spacing 4
                box_wrap True

                if renpy.variant("pc"):

                    frame:
                        background Solid("#3365")
                        style_prefix "radio"
                        has vbox
                        spacing 2
                        label _("View Universe")
                        textbutton _("Window") action Preference("display", "window")
                        textbutton _("Fullscreen") action Preference("display", "fullscreen")

                #vbox:
                #    style_prefix "radio"
                #    label _("Rollback Side")
                #    textbutton _("Disable") action Preference("rollback side", "disable")
                #    textbutton _("Left") action Preference("rollback side", "left")
                #    textbutton _("Right") action Preference("rollback side", "right")

                frame:
                    background Solid("#3365")
                    style_prefix "check"
                    has vbox
                    spacing 2
                    label _("Fast Forward")
                    textbutton _("Unseen Text") action Preference("skip", "toggle")
                    textbutton _("After Choices") action Preference("after choices", "toggle")
                    textbutton _("Transitions") action InvertSelected(Preference("transitions", "toggle"))

                ## Additional vboxes of type "radio_pref" or "check_pref" can be
                ## added here, to add additional creator-defined preferences.

            null width 4

            vbox:
                style_prefix "slider"
                box_wrap True
                spacing 4

                frame:
                    background Solid("#3365")
                    has vbox

                    label _("Text Speed")

                    bar value Preference("text speed")
                    null height 26

                    label _("Auto-Forward Time")

                    bar value Preference("auto-forward time")
                    null height 26

                frame:
                    background Solid("#3365")
                    has vbox

                    if config.has_music:
                        label _("Music Volume")

                        bar value Preference("music volume")
                        null height 26

                    if config.has_sound:

                        label _("Sound Volume")

                        #hbox:
                        bar value Preference("sound volume")

                        #    if config.sample_sound:
                        #        textbutton _("Test") action Play("sound", config.sample_sound)

                    if config.has_music or config.has_sound or config.has_voice:
                        null height gui.pref_spacing

                        textbutton _("Mute All"):
                            action Preference("all mute", "toggle")
                            style "mute_all_button"

    textbutton _("Language...") action ShowMenu("language") xalign .95 yalign .05 #activate_sound "music/choice2.wav"


style pref_label is gui_label
style pref_label_text is gui_label_text
style pref_vbox is vbox

style radio_label is pref_label
style radio_label_text is pref_label_text
style radio_button is gui_button
style radio_button_text is gui_button_text
style radio_vbox is pref_vbox

style check_label is pref_label
style check_label_text is pref_label_text
style check_button is gui_button
style check_button_text is gui_button_text
style check_vbox is pref_vbox

style slider_label is pref_label
style slider_label_text is pref_label_text
style slider_slider is gui_slider
style slider_button is gui_button
style slider_button_text is gui_button_text
style slider_pref_vbox is pref_vbox

style mute_all_button is check_button
style mute_all_button_text is check_button_text

style pref_label:
    #top_margin gui.pref_spacing
    bottom_margin 2

style pref_label_text:
    yalign 1.0
    color "#fff"

# style check_frame:
#     padding (12,12)
# style radio_frame:
#     padding (12,12)
# style slider_frame:
#     padding (12,12)

style pref_vbox:
    xsize 300

style radio_vbox:
    spacing gui.pref_button_spacing

style radio_button:
    properties gui.button_properties("radio_button")
    foreground "gui/button/radio_[prefix_]foreground.png"
    idle_background Solid("#3365")
    hover_background Solid("#BBF3")
    size_group "pref"
    yminimum 60
    activate_sound "music/choice.wav"

style radio_button_text:
    properties gui.button_text_properties("radio_button")

style check_vbox:
    spacing gui.pref_button_spacing

style check_button:
    properties gui.button_properties("check_button")
    foreground "gui/button/check_[prefix_]foreground.png"
    idle_background Solid("#3365")
    hover_background Solid("#BBF3")
    size_group "pref"
    yminimum 60
    activate_sound "music/choice.wav"

style check_button_text:
    properties gui.button_text_properties("check_button")

style slider_slider:
    xsize 350

style slider_button:
    properties gui.button_properties("slider_button")
    yalign 0.5
    left_margin 10

style slider_button_text:
    properties gui.button_text_properties("slider_button")

style slider_vbox:
    xsize 450


## History screen ##############################################################
##
## This is a screen that displays the dialogue history to the player. While
## there isn't anything special about this screen, it does have to access the
## dialogue history stored in _history_list.
##
## https://www.renpy.org/doc/html/history.html

screen history():

    tag menu

    ## Avoid predicting this screen, as it can be very large.
    predict False

    use game_menu(_("History"), scroll=("vpgrid" if gui.history_height else "viewport"), yinitial=1.0):

        style_prefix "history"

        for h in _history_list:

            window:
                background Solid("#3365")

                ## This lays things out properly if history_height is None.
                has fixed:
                    yfit True

                if h.who:

                    label h.who:
                        style "history_name"
                        substitute False

                        ## Take the color of the who text from the Character, if
                        ## set.
                        if "color" in h.who_args:
                            text_color h.who_args["color"]

                $ what = renpy.filter_text_tags(h.what, allow=gui.history_allow_tags)
                text what:
                    substitute False

        if not _history_list:
            label _("The dialogue history is empty.")

    textbutton _("Memories") action ShowMenu("memories") xalign .95 yalign .05


## This determines what tags are allowed to be displayed on the history screen.

define gui.history_allow_tags = set()


style history_window is empty

style history_name is gui_label
style history_name_text is gui_label_text
style history_text is gui_text

style history_text is gui_text

style history_label is gui_label
style history_label_text is gui_label_text

style history_window:
    xfill True
    ysize gui.history_height

style history_name:
    xpos gui.history_name_xpos
    xanchor gui.history_name_xalign
    ypos gui.history_name_ypos
    xsize gui.history_name_width

style history_name_text:
    min_width gui.history_name_width
    text_align gui.history_name_xalign
    bold gui.history_name_bold

style history_text:
    xpos gui.history_text_xpos
    ypos gui.history_text_ypos
    xanchor gui.history_text_xalign
    xsize gui.history_text_width
    min_width gui.history_text_width
    text_align gui.history_text_xalign
    layout ("subtitle" if gui.history_text_xalign else "tex")

style history_label:
    xfill True

style history_label_text:
    xalign 0.5


## Help screen #################################################################
##
## A screen that gives information about key and mouse bindings. It uses other
## screens (keyboard_help, mouse_help, and gamepad_help) to display the actual
## help.

screen help():

    tag menu

    default device = "keyboard"

    use game_menu(_("Help"), scroll="viewport"):


        frame:
            style_prefix "help"
            background Solid("#3365")
            has vbox
            spacing 15
            label _("How to Play") style "memories_label"

            hbox:

                textbutton _("Keyboard") action SetScreenVariable("device", "keyboard")
                textbutton _("Mouse") action SetScreenVariable("device", "mouse")

                if GamepadExists():
                    textbutton _("Gamepad") action SetScreenVariable("device", "gamepad")


            vpgrid:
                xysize (800,360)
                cols 1
                yinitial 0
                xfill True

                scrollbars "vertical"
                mousewheel True
                draggable True
                pagekeys True

                side_yfill True

                spacing gui.help_spacing
                if device == "keyboard":
                    use keyboard_help
                elif device == "mouse":
                    use mouse_help
                elif device == "gamepad":
                    use gamepad_help


screen keyboard_help():

    hbox:
        label _("Enter")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Space ")
        text _("Advances dialogue without selecting choices.")

    hbox:
        label _("Arrow Keys")
        text _("Navigate the interface.")

    hbox:
        label _("Escape")
        text _("Accesses the game menu.")

    hbox:
        label _("Ctrl")
        text _("Skips dialogue while held down.")

    hbox:
        label _("Tab")
        text _("Toggles dialogue skipping.")

    hbox:
        label _("Page Up")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Page Down")
        text _("Rolls forward to later dialogue.")

    hbox:
        label "H"
        text _("Hides the user interface.")

    hbox:
        label "S"
        text _("Takes a screenshot.")

    hbox:
        label "V"
        text _("Toggles assistive {a=https://www.renpy.org/l/voicing}self-voicing{/a}.")


screen mouse_help():

    hbox:
        label _("Left Click")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Middle Click")
        text _("Hides the user interface.")

    hbox:
        label _("Right Click")
        text _("Accesses the game menu.")

    hbox:
        label _("Mouse Wheel Up") #text_size 32
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Mouse Wheel Down")
        text _("Rolls forward to later dialogue.")


screen gamepad_help():

    hbox:
        label _("Right Trigger\nA/Bottom Button")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Left Trigger\nLeft Shoulder")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Right Shoulder")
        text _("Rolls forward to later dialogue.")


    hbox:
        label _("D-Pad, Sticks")
        text _("Navigate the interface.")

    hbox:
        label _("Start, Guide")
        text _("Accesses the game menu.")

    hbox:
        label _("Y/Top Button")
        text _("Hides the user interface.")

    textbutton _("Calibrate") action GamepadCalibrate()


style help_button is gui_button
style help_button_text is gui_button_text
style help_label is gui_label
style help_label_text is gui_label_text
style help_text is gui_text

style help_button:
    properties gui.button_properties("help_button")
    xmargin 2#8
    xpadding 20
    idle_background Solid("#3365")
    hover_background Solid("#FFF4")

style help_button_text:
    properties gui.button_text_properties("help_button")

style help_label:
    xsize 265
    right_padding 20

style help_label_text:
    size gui.help_text_size
    xalign 1.0
    text_align 1.0

style help_text:
    size gui.help_text_size


################################################################################
## Additional screens
################################################################################


## Confirm screen ##############################################################
##
## The confirm screen is called when Ren'Py wants to ask the player a yes or no
## question.
##
## https://www.renpy.org/doc/html/screen_special.html#confirm

screen confirm(message, yes_action, no_action):

    ## Ensure other screens do not get input while this screen is displayed.
    modal True

    zorder 200

    style_prefix "confirm"

    if main_menu:
        add "black"
    else:
        add "gui/overlay/confirm.png"

    frame:
        yalign .35
        xpadding 180

        vbox:
            xalign .5
            spacing 30

            label _(message):
                style "confirm_prompt"
                xalign 0.5

            hbox:
                xalign 0.5
                spacing 100

                textbutton _("Yes") action yes_action
                textbutton _("No") action no_action

    ## Right-click and escape answer "no".
    key "game_menu" action no_action


style confirm_frame is gui_frame
style confirm_prompt is gui_prompt
style confirm_prompt_text is gui_prompt_text
style confirm_button is gui_medium_button
style confirm_button_text is gui_medium_button_text

style confirm_frame:
    background Solid("#3365")
    #background Frame([ "gui/confirm_frame.png", "gui/frame.png"], gui.confirm_frame_borders, tile=gui.frame_tile)
    padding gui.confirm_frame_borders.padding
    xalign .5
    yalign .5

style confirm_prompt_text:
    text_align 0.5
    layout "subtitle"
    outlines [(2,"#000",0,0)]
    size gui.confirm_prompt_text_size

style confirm_button:
    properties gui.button_properties("confirm_button")
    idle_background Solid("#3365")
    hover_background Solid("#FFF4")
    xsize 200

style confirm_button_text:
    properties gui.button_text_properties("confirm_button")

#efine gui.DELETE_SAVE = _("Are you sure you want to delete this save point?")
#define gui.OVERWRITE_SAVE = _("Are you sure you want to overwrite this save point?")
#define gui.LOADING = _("Only saved memories are retained when warping.\nWarp anyway?")
#define gui.MAIN_MENU = _("Are you sure you want to abandon this timeline?")


## Skip indicator screen #######################################################
##
## The skip_indicator screen is displayed to indicate that skipping is in
## progress.
##
## https://www.renpy.org/doc/html/screen_special.html#skip-indicator

screen skip_indicator():

    zorder 100
    style_prefix "skip"

style skip_frame is empty
style skip_text is gui_text
style skip_triangle is skip_text

style skip_frame:
    ypos gui.skip_ypos
    background Frame("gui/skip.png", gui.skip_frame_borders, tile=gui.frame_tile)
    padding gui.skip_frame_borders.padding

style skip_text:
    size gui.notify_text_size


## Notify screen ###############################################################
##
## The notify screen is used to show the player a message. (For example, when
## the game is quicksaved or a screenshot has been taken.)
##
## https://www.renpy.org/doc/html/screen_special.html#notify-screen

screen notify(message):

    zorder 100
    style_prefix "notify"

    frame at notify_appear:
        text "[message!tq]"

    timer 3.25 action Hide('notify')


transform notify_appear:
    on show:
        alpha 0 xpos 8 ypos -20
        linear .25 alpha 1.0 ypos 5
    on hide:
        linear .5 xpos 8 alpha 0 ypos -40


style notify_frame is empty
style notify_text is gui_text

style notify_frame:
    ypos gui.notify_ypos

    background Frame("gui/notify.png", gui.notify_frame_borders, tile=gui.frame_tile)
    padding gui.notify_frame_borders.padding

style notify_text:
    properties gui.text_properties("notify")
    color "#0cf"


## NVL screen ##################################################################
##
## This screen is used for NVL-mode dialogue and menus.
##
## https://www.renpy.org/doc/html/screen_special.html#nvl


screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            spacing gui.nvl_spacing

        ## Displays dialogue in either a vpgrid or the vbox.
        if gui.nvl_height:

            vpgrid:
                cols 1
                yinitial 1.0

                use nvl_dialogue(dialogue)

        else:

            use nvl_dialogue(dialogue)

        ## Displays the menu, if given. The menu may be displayed incorrectly if
        ## config.narrator_menu is set to True, as it is above.
        for i in items:

            textbutton i.caption:
                action i.action
                style "nvl_button"

    add SideImage() xalign 0.0 yalign 1.0


screen nvl_dialogue(dialogue):

    for d in dialogue:

        window:
            id d.window_id

            fixed:
                yfit gui.nvl_height is None

                if d.who is not None:

                    text d.who:
                        id d.who_id

                text d.what:
                    id d.what_id


## This controls the maximum number of NVL-mode entries that can be displayed at
## once.
define config.nvl_list_length = gui.nvl_list_length

style nvl_window is default
style nvl_entry is default

style nvl_label is say_label
style nvl_dialogue is say_dialogue

style nvl_button is button
style nvl_button_text is button_text

style nvl_window:
    xfill True
    yfill True

    background "gui/nvl.png"
    padding gui.nvl_borders.padding

style nvl_entry:
    xfill True
    ysize gui.nvl_height

style nvl_label:
    xpos gui.nvl_name_xpos
    xanchor gui.nvl_name_xalign
    ypos gui.nvl_name_ypos
    yanchor 0.0
    xsize gui.nvl_name_width
    min_width gui.nvl_name_width
    text_align gui.nvl_name_xalign

style nvl_dialogue:
    xpos gui.nvl_text_xpos
    xanchor gui.nvl_text_xalign
    ypos gui.nvl_text_ypos
    xsize gui.nvl_text_width
    min_width gui.nvl_text_width
    text_align gui.nvl_text_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_thought:
    xpos gui.nvl_thought_xpos
    xanchor gui.nvl_thought_xalign
    ypos gui.nvl_thought_ypos
    xsize gui.nvl_thought_width
    min_width gui.nvl_thought_width
    text_align gui.nvl_thought_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_button:
    properties gui.button_properties("nvl_button")
    xpos gui.nvl_button_xpos
    xanchor gui.nvl_button_xalign

style nvl_button_text:
    properties gui.button_text_properties("nvl_button")


##############################################################################
screen memories():
    tag menu

    use game_menu(_("Memories"), scroll="viewport"):

        frame:
            style_group "memories"
            has vbox
            label _("Memories")
            spacing 10

            vpgrid:
                xysize (800,320)
                cols 1
                yinitial 0
                xfill True

                scrollbars "vertical"
                mousewheel True
                draggable True
                pagekeys True

                side_yfill True

                frame:
                    background None
                    xsize 760
                    has vbox
                    spacing 24
                    use memorylist

            if persistent.round3clear:
                vbox:
                    spacing 10
                    textbutton _("Partially erase memories...") action Start("partialreset")
                    textbutton _("Completely erase all memories...") action Start("resetdata")

    if not main_menu:
        textbutton _("History") action ShowMenu("history") xalign .95 yalign .05

screen memorylist():
        #vbox:
        #    spacing 10
    if persistent.metspace:
        text _("Someone's here - I met a girl in the void.")
    if persistent.loop1:
        text _("She's going to cry - I wanted to stop her from crying.")
    if persistent.lostspace:
        text _("She's gone... - When I opened my eyes, her light was gone.")
    if persistent.triedrewind:
        text _("Her demise - Such a horrible thing happened to Space...! How can I change this?")
    if persistent.round1clear:
        text _("An ending - Nil locked me in a loop after taking Space away....")
    if persistent.round2clear:
        text _("Another ending - We fell asleep together... I lost her again.")
    if persistent.round3clear:
        text _("Again and Again - There was just nothing I could do for Space on my own.")

#page2
    if persistent.round3clear:
        if persistent.nilstory:
            text _("Nil's story - I listened to what Nil had gone through.")
        else:
            text _("(memory locked)")
        if persistent.promise:
            text _("You promised - I promised to find Nil first.")
        else:
            text _("(memory locked)")
        if persistent.firstkiss:
            text _("We kissed - ...and Space's light washed away all the darkness.")
        else:
            text _("(memory locked)")

    if persistent.spacememory:
        text _("Space Ending - Nil never bothered us again. But... was it okay to leave her all alone?")
    else:
        text _("(ending locked)")
    if persistent.nilmemory:
        text _("Nil Ending - I didn't go back for Space... would she forgive me?")
    else:
        text _("(ending locked)")

    if persistent.clearmemory:
        text _("True Beginning - Nil, Space, and I were able to live together happily for all eternity.")
    else:
        text _("(ending locked)")

style memories_label_text:
    color "#fff"
style memories_frame:
    background Solid("#3365")
    xfill True
    xsize 800
    xalign .3
    yalign .5
style memories_button is gui_button:
    idle_background Solid("#3365")
    hover_background Solid("#FFF4")


################################################################################
## Mobile Variants
################################################################################

# style pref_vbox:
#     variant "medium"
#     xsize 450

## Since a mouse may not be present, we replace the quick menu with a version
## that uses fewer and bigger buttons that are easier to touch.
screen quick_menu():
    variant "touch"

    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0


            textbutton _("Reset") action MainMenu()
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Hide Textbox") action HideInterface() activate_sound None
            textbutton _("Menu") action ShowMenu("history")

        imagebutton auto "gui/button/rewind_%s.png" xalign 0 yalign 1.0 action Rollback()
        textbutton _("Rewind") xalign 0 yalign 1.0 xoffset -16 action Rollback() style "quick_button"
        imagebutton auto "gui/button/ff_%s.png" xalign 1.0 yalign 1.0 action Skip() alternate Skip(fast=True, confirm=True)
        textbutton _("Fast Forward") xalign 1.0 yalign 1.0 xoffset 32 action Skip() alternate Skip(fast=True, confirm=True) style "quick_button"


style window:
    variant "small"
    background "gui/phone/textbox.png"

style radio_button:
    variant "small"
    foreground "gui/phone/button/radio_[prefix_]foreground.png"

style check_button:
    variant "small"
    foreground "gui/phone/button/check_[prefix_]foreground.png"

style nvl_window:
    variant "small"
    background "gui/phone/nvl.png"

style main_menu_frame:
    variant "small"
    background "gui/phone/overlay/main_menu.png"

style game_menu_outer_frame:
    variant "small"
    background "gui/phone/overlay/game_menu.png"

#style game_menu_navigation_frame:
#    variant "small"
#    xsize 340

# style game_menu_content_frame:
#     variant "small"
#     top_margin 0

# style pref_vbox:
#     variant "small"
#     xsize 400

style bar:
    variant "small"
    ysize gui.bar_size
    left_bar Frame("gui/phone/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/phone/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    variant "small"
    xsize gui.bar_size
    top_bar Frame("gui/phone/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/phone/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    variant "small"
    ysize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    variant "small"
    xsize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    variant "small"
    ysize gui.slider_size
    base_bar Frame("gui/phone/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/horizontal_[prefix_]thumb.png"

style vslider:
    variant "small"
    xsize gui.slider_size
    base_bar Frame("gui/phone/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/vertical_[prefix_]thumb.png"

# style slider_pref_vbox:
#     variant "small"
#     xsize None
#
# style slider_pref_slider:
#     variant "small"
#     xsize 600
