﻿################################################################################
## Initialization
################################################################################

init offset = -1


################################################################################
## Styles
################################################################################

style default:
    properties gui.text_properties()
    language gui.language

style input:
    properties gui.text_properties("input", accent=True)
    adjust_spacing False

style hyperlink_text:
    properties gui.text_properties("hyperlink", accent=True)
    hover_underline False
    idle_color "#fff"
    hover_color "#ffe381"

style gui_text:
    properties gui.text_properties("interface")
    outlines pasol

style button:
    properties gui.button_properties("button")
    activate_sound "audio/blip.wav"

style button_text is gui_text:
    properties gui.text_properties("button")
    yalign 0.5


style label_text is gui_text:
    properties gui.text_properties("label")
    color "#fff"
    outlines pasol

style prompt_text is gui_text:
    properties gui.text_properties("prompt")


style bar:
    ysize gui.bar_size
    left_bar Frame("gui/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    xsize gui.bar_size
    top_bar Frame("gui/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    ysize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    xsize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    ysize gui.slider_size
    base_bar Frame("gui/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/slider/horizontal_[prefix_]thumb.png"

style vslider:
    xsize gui.slider_size
    base_bar Frame("gui/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/slider/vertical_[prefix_]thumb.png"


style frame:
    padding gui.frame_borders.padding
    background Frame("gui/frame.png", gui.frame_borders, tile=gui.frame_tile)



################################################################################
## In-game screens
################################################################################


## Say screen ##################################################################
##
## The say screen is used to display dialogue to the player. It takes two
## parameters, who and what, which are the name of the speaking character and
## the text to be displayed, respectively. (The who parameter can be None if no
## name is given.)
##
## This screen must create a text displayable with id "what", as Ren'Py uses
## this to manage text display. It can also create displayables with id "who"
## and id "window" to apply style properties.
##
## https://www.renpy.org/doc/html/screen_special.html#say

screen say(who, what):
    style_prefix "say"

    window:
        id "window"

        if who is not None:

            window:
                id "namebox"
                style "namebox"
                text who id "who" #bold True

        text what id "what"


    ## If there's a side image, display it above the text. Do not display on the
    ## phone variant - there's no room.
    if not renpy.variant("small"):
        add SideImage() xalign 0.0 yalign 1.0


## Make the namebox available for styling through the Character object.
init python:
    config.character_id_prefixes.append('namebox')

style window is default
style say_label is default
style say_dialogue is default
style say_thought is say_dialogue

style namebox is default
style namebox_label is say_label


style window:
    xalign 0.5
    xfill True
    yalign gui.textbox_yalign
    ysize gui.textbox_height

    background Image("gui/textbox.png", xalign=0.5, yalign=1.0)

style namebox:
    xpos gui.name_xpos
    xanchor gui.name_xalign
    xsize gui.namebox_width
    ypos gui.name_ypos
    ysize gui.namebox_height

    background Frame("gui/namebox.png", gui.namebox_borders, tile=gui.namebox_tile, xalign=gui.name_xalign)
    padding gui.namebox_borders.padding

style say_label:
    properties gui.text_properties("name", accent=True)
    xalign gui.name_xalign
    yalign 0.5

style say_dialogue:
    properties gui.text_properties("dialogue")

    xpos gui.dialogue_xpos
    xsize gui.dialogue_width
    ypos gui.dialogue_ypos
    line_overlap_split gui.dialogue_text_line_overlap_split


## Input screen ################################################################
##
## This screen is used to display renpy.input. The prompt parameter is used to
## pass a text prompt in.
##
## This screen must create an input displayable with id "input" to accept the
## various input parameters.
##
## https://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):
    style_prefix "input"

    window:

        vbox:
            xalign gui.dialogue_text_xalign
            xpos gui.dialogue_xpos
            xsize gui.dialogue_width
            ypos gui.dialogue_ypos

            text prompt style "input_prompt"
            input id "input"

style input_prompt is default

style input_prompt:
    xalign gui.dialogue_text_xalign
    properties gui.text_properties("input_prompt")

style input:
    xalign gui.dialogue_text_xalign
    xmaximum gui.dialogue_width


## Choice screen ###############################################################
##
## This screen is used to display the in-game choices presented by the menu
## statement. The one parameter, items, is a list of objects, each with caption
## and action fields.
##
## https://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):
    style_prefix "choice"

    vbox:
        for i in items:
            textbutton i.caption action i.action


## When this is true, menu captions will be spoken by the narrator. When false,
## menu captions will be displayed as empty buttons.
define config.narrator_menu = True


style choice_vbox is vbox
style choice_button is button
style choice_button_text is button_text

style choice_vbox:
    xalign 0.5
    ypos 270
    yanchor 0.5

    spacing gui.choice_spacing

style choice_button is default:
    properties gui.button_properties("choice_button")
    activate_sound "audio/select.wav"

style choice_button_text is default:
    properties gui.button_text_properties("choice_button")


## Quick Menu screen ###########################################################
##
## The quick menu is displayed in-game to provide easy access to the out-of-game
## menus.

screen quick_menu():

    ## Ensure this appears on top of other screens.
    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"
            spacing 30

            xalign 0.5
            yalign 1.0

            textbutton _("Back") action Rollback()
            textbutton _("History") action ShowMenu('history')
            textbutton _("Skip") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Save") action ShowMenu('save')
            #textbutton _("Q.Save") action QuickSave()
            #textbutton _("Q.Load") action QuickLoad()
            textbutton _("Options") action ShowMenu('preferences')


## This code ensures that the quick_menu screen is displayed in-game, whenever
## the player has not explicitly hidden the interface.
init python:
    config.overlay_screens.append("quick_menu")

default quick_menu = True

style quick_button is default
style quick_button_text is button_text

style quick_button:
    properties gui.button_properties("quick_button")
    activate_sound "audio/menubutton.wav"

style quick_button_text:
    properties gui.button_text_properties("quick_button")
    outlines [(2,"#FFF",0,0)]


################################################################################
## Main and Game Menu Screens
################################################################################

## Navigation screen ###########################################################
##
## This screen is included in the main and game menus, and provides navigation
## to other menus, and to start the game.

screen navigation():

    hbox:
        style_prefix "navigation"

        yalign 0.88
        xalign .5

        spacing gui.navigation_spacing

        if main_menu:

            textbutton _("Start") action Start() activate_sound "audio/start.wav"

        else:

            textbutton _("History") action ShowMenu("history")

            textbutton _("Save") action ShowMenu("save")

        textbutton _("Load") action ShowMenu("load")

        textbutton _("Options") action ShowMenu("preferences")

        textbutton _("About") action ShowMenu("about")

        if persistent.endclear:
            textbutton _("Ending List") action ShowMenu("endings")

        if renpy.variant("pc"):

            ## The quit button is banned on iOS and unnecessary on Android.
            textbutton _("Quit") action Quit(confirm=not main_menu)
    if renpy.variant("pc"):
        imagebutton auto "gui/button/helpme_%s.png" action ShowMenu("help") xalign .98 yalign .03 activate_sound "audio/blip.wav"


style navigation_button is gui_button
style navigation_button_text is gui_button_text

style navigation_button:
    #size_group "navigation"
    properties gui.button_properties("navigation_button")

style navigation_button_text:
    properties gui.button_text_properties("navigation_button")
    xalign .5
    selected_idle_color "#ffcbde"


## Main Menu screen ############################################################
##
## Used to display the main menu when Ren'Py starts.
##
## https://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    ## This ensures that any other menu screen is replaced.
    tag menu

    style_prefix "main_menu"

    add gui.main_menu_background
    add "mmbgani"
    add "driftyclouds"
    add "title" xalign .1 yalign .1

    hbox:
        pos (13,184)
        spacing -40
        if persistent.syrupend:
            add "mmsyrup2"
        else:
            add "mmsyrup"
        null width 16
        if persistent.gumdropend:
            add "mmgum2"
        else:
            add "mmgum"
        null width 38
        if persistent.pastilleend:
            add "mmpas2"
        else:
            add "mmpas"
        if persistent.butterscotchend:
            add "mmbs2"
        else:
            add "mmbs"
        null width 36
        if persistent.toffeeend:
            add "mmtof2"
        else:
            add "mmtof"
    add "hint" xpos 18 yalign .99

    ## This empty frame darkens the main menu.
    #frame:
    #    pass

    ## The use statement includes another screen inside this one. The actual
    ## contents of the main menu are in the navigation screen.
    vbox:
        style_group "mm"
        xalign .97
        yalign .55
        spacing 20
        textbutton _("Start Game") action Start() activate_sound "audio/start.wav"
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Options") action ShowMenu("preferences")
        if renpy.variant("pc"):
            textbutton _("Quit") action Quit(confirm=not main_menu)

    if gui.show_name:
        text "[config.name!t]" style "main_menu_title"

    if renpy.variant("touch"):
        if persistent.endclear:
            imagebutton auto "gui/phone/button/mygames_%s.png" action OpenURL("https://nomnomnami.carrd.co/") align (.98,.06)

style main_menu_frame is empty
style main_menu_vbox is vbox
style main_menu_text is gui_text
style main_menu_title is main_menu_text
style main_menu_version is main_menu_text

style main_menu_frame:
    xsize 280
    yfill True

    background "gui/overlay/main_menu.png"

style main_menu_vbox:
    xalign 1.0
    xoffset -20
    xmaximum 800
    yalign 1.0
    yoffset -20

style main_menu_text:
    properties gui.text_properties("main_menu")

style main_menu_title:
    properties gui.text_properties("title")
    color "#fff"
    outlines [(4, "#333", 0, 0)]
    xalign .1
    yalign .1

style main_menu_version:
    properties gui.text_properties("version")

style mm_text:
    size gui.interface_text_size
    outlines [(3, "#333", 0, 0)]
style mm_text:
    variant "small"
    size gui.mm_text_size
style mm_button:
    size_group "mm"
style mm_button_text:
    size gui.about_large_text_size
    bold gui.navigation_button_text_bold
    idle_color "#fff"
    outlines [(4, "#333", 0, 0)]
    xalign .5
    text_align .5


## Game Menu screen ############################################################
##
## This lays out the basic common structure of a game menu screen. It's called
## with the screen title, and displays the background, title, and navigation.
##
## The scroll parameter can be None, or one of "viewport" or "vpgrid". When
## this screen is intended to be used with one or more children, which are
## transcluded (placed) inside it.

screen game_menu(title, scroll=None, yinitial=0.0):

    style_prefix "game_menu"

    #if main_menu:
    #    add gui.main_menu_background
    #else:
    add gui.game_menu_background

    frame xysize(1020,520):
        style "game_menu_outer_frame"

        frame :
            style "game_menu_content_frame"

            if scroll == "viewport":

                viewport:
                    yinitial yinitial
                    scrollbars "vertical"
                    mousewheel True
                    draggable True
                    pagekeys True

                    side_yfill True

                    vbox:
                        transclude

            elif scroll == "vpgrid":

                vpgrid:
                    cols 1
                    yinitial yinitial

                    scrollbars "vertical"
                    mousewheel True
                    draggable True
                    pagekeys True

                    side_yfill True

                    transclude

            else:

                transclude

    use navigation

    if not main_menu:
        textbutton _("Main Menu"):
            style "return_button"
            action MainMenu()
            xalign .04

    textbutton _("Return"):
        style "return_button"

        action Return()

    label title

    if main_menu:
        key "game_menu" action ShowMenu("main_menu")


style game_menu_outer_frame is empty
style game_menu_navigation_frame is empty
style game_menu_content_frame is empty
style game_menu_viewport is gui_viewport
style game_menu_side is gui_side
style game_menu_scrollbar is gui_vscrollbar

style game_menu_label is gui_label
style game_menu_label_text is gui_label_text

style return_button is navigation_button
style return_button_text is navigation_button_text

style game_menu_outer_frame:
    bottom_padding 10
    top_padding 40
    xalign .5
    yalign .3

    background Frame("gui/frame.png",10,10)

style game_menu_content_frame:
    xmargin 60
    ymargin 10
    padding (10,10)
    background Frame("gui/frame2.png",10,10)

style game_menu_viewport:
    xsize 920

style game_menu_vscrollbar:
    unscrollable gui.unscrollable

style game_menu_side:
    spacing 10
    xoffset 30

style game_menu_label:
    xpos 150
    ysize 136

style game_menu_label_text:
    size gui.title_text_size
    outlines [(5, "#cc6600", 0, 0)]
    yalign 0.5

style return_button:
    xalign .96
    yalign .98
    activate_sound None


## About screen ################################################################
##
## This screen gives credit and copyright information about the game and Ren'Py.
##
## There's nothing special about this screen, and hence it also serves as an
## example of how to make a custom screen.

screen about():

    tag menu

    ## This use statement includes the game_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the game_menu
    ## screen.
    use game_menu(_("About"), scroll="viewport"):

        style_prefix "about"
        vbox:
            null height 10
            imagebutton idle "gui/patreon ad.png" action OpenURL("https://www.patreon.com/nomnomnami") xalign .5 focus_mask None
            null height 20
            text _("[config.name!t] * Version [config.version!t]") style "about_large_text"
            null height 10
            frame:
                has vbox
                null height 10
                ## gui.about is usually set in options.rpy.
                if gui.about:
                    text "[gui.about!t]\n"

                text _("Made with {a=https://www.renpy.org/}Ren'Py{/a} [renpy.version_only].\n\n{size=-5}[renpy.license!t]{/size}")



## This is redefined in options.rpy to add text to the about screen.
define gui.about = ""

style about_frame is pref_frame:
    xsize 780

style about_label is gui_label
style about_label_text is gui_label_text
style about_text is gui_text

style about_large_text is about_text:
    size gui.about_large_text_size
    color "#fff"

style about_label_text:
    size gui.label_text_size


## Load and Save screens #######################################################
##
## These screens are responsible for letting the player save the game and load
## it again. Since they share nearly everything in common, both are implemented
## in terms of a third screen, file_slots.
##
## https://www.renpy.org/doc/html/screen_special.html#save https://
## www.renpy.org/doc/html/screen_special.html#load

screen save():

    tag menu

    use file_slots(_("Save"))


screen load():

    tag menu

    use file_slots(_("Load"))


screen file_slots(title):

    default page_name_value = FilePageNameInputValue(pattern=_("Page {}"), auto=_("Automatic saves"), quick=_("Quick saves"))

    use game_menu(title):

        fixed:

            ## This ensures the input will get the enter event before any of the
            ## buttons do.
            order_reverse True

            ## The page name, which can be edited by clicking on a button.
            button:
                yoffset -26
                style "page_label"

                key_events True
                xalign 0.5
                action page_name_value.Toggle()

                input:
                    style "page_label_text"
                    value page_name_value

            ## The grid of file slots.
            grid gui.file_slot_cols gui.file_slot_rows:
                style_prefix "slot"

                xalign 0.5
                yalign 1.0

                spacing gui.slot_spacing

                for i in range(gui.file_slot_cols * gui.file_slot_rows):

                    $ slot = i + 1

                    button:
                        action FileAction(slot)

                        has vbox

                        add FileScreenshot(slot) xalign 0.5

                        text FileTime(slot, format=_("{#file_time}%m/%d/%Y * %H:%M"), empty=_("empty slot")):
                            style "slot_time_text"
                        text FileSaveName(slot):
                            style "slot_name_text"

                        key "save_delete" action FileDelete(slot)

            imagebutton auto "gui/button/filepagebuttonl_%s.png" action FilePagePrevious() xalign .08 yoffset 20 activate_sound "audio/menubutton.wav"
            imagebutton auto "gui/button/filepagebuttonr_%s.png" action FilePageNext() xalign .92 yoffset 20 activate_sound "audio/menubutton.wav"


style page_label is gui_label
style page_label_text is gui_label_text
style page_button is gui_button
style page_button_text is gui_button_text

style slot_button is gui_button
style slot_button_text is gui_button_text:
    outlines [(0,None,0,0)]
style slot_time_text is slot_button_text:
    color "#FB6199"
style slot_name_text is slot_button_text:
    color "#FB6199"
    selected_idle_color "#ffa6c6"
    hover_color "#993C5F"

style page_label:
    xpadding 50
    ypadding 3

style page_label_text:
    text_align 0.5
    layout "subtitle"
    hover_color gui.hover_color
    outlines [(3, "#b04d72", 0, 0)]

style page_button:
    properties gui.button_properties("page_button")

style page_button_text:
    properties gui.button_text_properties("page_button")

style slot_button:
    properties gui.button_properties("slot_button")

style slot_button_text:
    properties gui.button_text_properties("slot_button")


## Preferences screen ##########################################################
##
## The preferences screen allows the player to configure the game to better suit
## themselves.
##
## https://www.renpy.org/doc/html/screen_special.html#preferences

screen preferences():

    tag menu

    use game_menu(_("Options"), scroll="viewport"):

        vbox:
            null height 10

            hbox:
                #box_wrap True
                spacing 16

                vbox:

                    frame:
                        style "pref_frame"
                        has vbox
                        style_prefix "radio"
                        label _("Display")
                        textbutton _("Window") action Preference("display", "window")
                        textbutton _("Fullscreen") action Preference("display", "fullscreen")
                    null height 10
                    frame:
                        style "pref_frame"
                        xsize 265
                        textbutton _("Language...") action ShowMenu("language") activate_sound "audio/menubutton.wav"

                frame:
                    style "pref_frame"
                    has vbox
                    style_prefix "radio"
                    label _("Rollback Side")
                    textbutton _("Disable") action Preference("rollback side", "disable")
                    textbutton _("Left") action Preference("rollback side", "left")
                    textbutton _("Right") action Preference("rollback side", "right")

                frame:
                    style "pref_frame"
                    has vbox
                    style_prefix "check"
                    label _("Skip")
                    textbutton _("Unseen Text") action Preference("skip", "toggle")
                    textbutton _("After Choices") action Preference("after choices", "toggle")
                    textbutton _("Transitions") action InvertSelected(Preference("transitions", "toggle"))

                ## Additional vboxes of type "radio_pref" or "check_pref" can be
                ## added here, to add additional creator-defined preferences.

            null height 10

            hbox:
                style_prefix "slider"
                spacing 20
                xalign .5

                frame:
                    style "pref_frame"
                    has vbox
                    xsize gui.textspeed_xsize
                    label _("Text Speed")
                    bar value Preference("text speed")

                    label _("Auto-Forward Time")
                    bar value Preference("auto-forward time")

                frame:
                    style "pref_frame"
                    hbox:
                        vbox:
                            label _("Music Volume")
                            hbox:
                                bar value Preference("music volume")
                            label _("Sound Volume")
                            hbox:
                                bar value Preference("sound volume")

                        imagebutton auto "gui/button/mute_%s.png" action Preference("all mute", "toggle") yalign .5 activate_sound "audio/menubutton.wav"


style pref_label is gui_label
style pref_label_text is gui_label_text
style pref_vbox is vbox

style radio_label is pref_label
style radio_label_text is pref_label_text
style radio_button is gui_button
style radio_button_text is gui_button_text
style radio_vbox is pref_vbox

style check_label is pref_label
style check_label_text is pref_label_text
style check_button is gui_button
style check_button_text is gui_button_text
style check_vbox is pref_vbox

style slider_label is pref_label
style slider_label_text is pref_label_text
style slider_slider is gui_slider
style slider_button is gui_button
style slider_button_text is gui_button_text
style slider_pref_vbox is pref_vbox

style mute_all_button is check_button
style mute_all_button_text is check_button_text

style pref_frame:
    background Frame("gui/history.png",15,15)
    padding (20,5)

style pref_label:
    top_margin gui.pref_spacing
    bottom_margin 2

style pref_label_text:
    yalign 1.0
    size gui.pref_label_text_size

style pref_vbox:
    xsize 225

style radio_vbox:
    spacing gui.pref_button_spacing

style radio_button:
    properties gui.button_properties("radio_button")
    foreground "gui/button/radio_[prefix_]foreground.png"

style radio_button_text:
    properties gui.button_text_properties("radio_button")
    idle_color gui.interface_text_color

style check_vbox:
    spacing gui.pref_button_spacing

style check_button:
    properties gui.button_properties("check_button")
    foreground "gui/button/check_[prefix_]foreground.png"

style check_button_text:
    properties gui.button_text_properties("check_button")
    idle_color gui.interface_text_color

style slider_slider:
    xsize 224
    left_bar "gui/slider/horizontal_idle_bar.png"
    right_bar "gui/slider/horizontal_hover_bar.png"
    thumb "gui/slider/horizontal_hover_thumb.png"
    thumb_offset 21
    left_gutter 20
    right_gutter 21

style slider_label_text:
    size gui.slider_label_text_size

style slider_button:
    properties gui.button_properties("slider_button")
    yalign 0.5
    left_margin 10

style slider_button_text:
    properties gui.button_text_properties("slider_button")

style slider_vbox:
    xsize 250


## History screen ##############################################################
##
## This is a screen that displays the dialogue history to the player. While
## there isn't anything special about this screen, it does have to access the
## dialogue history stored in _history_list.
##
## https://www.renpy.org/doc/html/history.html

screen history():

    tag menu

    ## Avoid predicting this screen, as it can be very large.
    predict False

    use game_menu(_("History"), scroll=("vpgrid" if gui.history_height else "viewport"), yinitial=1.0):

        style_prefix "history"

        for h in _history_list:

            window:

                ## This lays things out properly if history_height is None.
                has fixed:
                    yfit True

                if h.who:

                    label h.who:
                        style "history_name"
                        substitute False

                        ## Take the color of the who text from the Character, if
                        ## set.
                        if "color" in h.who_args:
                            text_color h.who_args["color"]

                $ what = renpy.filter_text_tags(h.what, allow=gui.history_allow_tags)
                frame:
                    background Frame("gui/history.png",15,15)
                    padding (10,5)
                    xpos gui.history_text_xpos
                    text what:
                        substitute False

        if not _history_list:
            label _("The dialogue history is empty.")


## This determines what tags are allowed to be displayed on the history screen.

define gui.history_allow_tags = set()


style history_window is empty

style history_name is gui_label
style history_name_text is gui_label_text

style history_label is gui_label
style history_label_text is gui_label_text

style history_window:
    xfill True
    ysize gui.history_height

style history_name:
    xpos gui.history_name_xpos
    xanchor gui.history_name_xalign
    ypos gui.history_name_ypos
    xsize gui.history_name_width

style history_name_text:
    min_width gui.history_name_width
    text_align gui.history_name_xalign
    bold False
    size gui.history_name_size

style history_text:
    size gui.history_text_size
    ypos gui.history_text_ypos
    xanchor gui.history_text_xalign
    xsize gui.history_text_width
    min_width gui.history_text_width
    text_align gui.history_text_xalign
    layout ("subtitle" if gui.history_text_xalign else "tex")
    color "#993c5f"

style history_label:
    xfill True

style history_label_text:
    xalign 0.5


## Help screen #################################################################
##
## A screen that gives information about key and mouse bindings. It uses other
## screens (keyboard_help, mouse_help, and gamepad_help) to display the actual
## help.

screen help():

    tag menu

    default device = "keyboard"

    use game_menu(_("Help"), scroll="viewport"):

        style_prefix "help"

        hbox:
            textbutton _("Keyboard") action SetScreenVariable("device", "keyboard")
            textbutton _("Mouse") action SetScreenVariable("device", "mouse")

            if GamepadExists():
                textbutton _("Gamepad") action SetScreenVariable("device", "gamepad")

        frame:
            vbox:
                spacing 15
                if device == "keyboard":
                    use keyboard_help
                elif device == "mouse":
                    use mouse_help
                elif device == "gamepad":
                    use gamepad_help


screen keyboard_help():

    hbox:
        label _("Enter")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Space")
        text _("Advances dialogue without selecting choices.")

    hbox:
        label _("Arrow Keys")
        text _("Navigate the interface.")

    hbox:
        label _("Escape")
        text _("Accesses the game menu.")

    hbox:
        label _("Ctrl")
        text _("Skips dialogue while held down.")

    hbox:
        label _("Tab")
        text _("Toggles dialogue skipping.")

    hbox:
        label _("Page Up")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Page Down")
        text _("Rolls forward to later dialogue.")

    hbox:
        label "H"
        text _("Hides the user interface.")

    hbox:
        label "S"
        text _("Takes a screenshot.")

    hbox:
        label "V"
        text _("Toggles assistive {a=https://www.renpy.org/l/voicing}self-voicing{/a}.")


screen mouse_help():

    hbox:
        label _("Left Click")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Middle Click")
        text _("Hides the user interface.")

    hbox:
        label _("Right Click")
        text _("Accesses the game menu.")

    hbox:
        label _("Mouse Wheel Up\nClick Rollback Side")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Mouse Wheel Down")
        text _("Rolls forward to later dialogue.")


screen gamepad_help():

    hbox:
        label _("Right Trigger\nA/Bottom Button")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Left Trigger\nLeft Shoulder")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Right Shoulder")
        text _("Rolls forward to later dialogue.")


    hbox:
        label _("D-Pad, Sticks")
        text _("Navigate the interface.")

    hbox:
        label _("Start, Guide")
        text _("Accesses the game menu.")

    hbox:
        label _("Y/Top Button")
        text _("Hides the user interface.")

    textbutton _("Calibrate") action GamepadCalibrate()


style help_button is gui_button
style help_button_text is gui_button_text
style help_label is gui_label
style help_label_text is gui_label_text
style help_text is gui_text

style help_button:
    properties gui.button_properties("help_button")
    xmargin 8
    activate_sound "audio/menubutton.wav"

style help_button_text:
    properties gui.button_text_properties("help_button")
    selected_idle_color "#ffcbde"

style help_label:
    xsize 350
    right_padding 20

style help_label_text:
    size gui.text_size
    xalign 1.0
    text_align 1.0

style help_frame is pref_frame:
    xsize 820
    ypadding 16



################################################################################
## Additional screens
################################################################################


## Confirm screen ##############################################################
##
## The confirm screen is called when Ren'Py wants to ask the player a yes or no
## question.
##
## https://www.renpy.org/doc/html/screen_special.html#confirm

screen confirm(message, yes_action, no_action):

    ## Ensure other screens do not get input while this screen is displayed.
    modal True

    zorder 200

    style_prefix "confirm"

    add "gui/overlay/confirm.png"

    frame:

        vbox:
            xalign .5
            yalign .5
            spacing 30

            label _(message):
                style "confirm_prompt"
                xalign 0.5

            hbox:
                xalign 0.5
                spacing 100

                textbutton _("Yes") action yes_action activate_sound "audio/start.wav"
                textbutton _("No") action no_action activate_sound "audio/bwoop.wav"

    ## Right-click and escape answer "no".
    key "game_menu" action no_action


style confirm_frame is gui_frame
style confirm_prompt is gui_prompt
style confirm_prompt_text is gui_prompt_text
style confirm_button is gui_medium_button
style confirm_button_text is gui_medium_button_text

style confirm_frame:
    background Frame([ "gui/confirm_frame.png", "gui/frame.png"], gui.confirm_frame_borders, tile=gui.frame_tile)
    padding gui.confirm_frame_borders.padding
    xalign .5
    yalign .35

style confirm_prompt_text:
    text_align 0.5
    layout "subtitle"
    color "#fff"

style confirm_button:
    properties gui.button_properties("confirm_button")

style confirm_button_text:
    properties gui.button_text_properties("confirm_button")


## Skip indicator screen #######################################################
##
## The skip_indicator screen is displayed to indicate that skipping is in
## progress.
##
## https://www.renpy.org/doc/html/screen_special.html#skip-indicator

screen skip_indicator():

    zorder 100
    style_prefix "skip"

    frame:
        yalign .03
        xalign 1.0

        hbox:
            #spacing 6

            text _("Skipping")

            text "." at delayed_blink(0.0, 1.0)
            text "." at delayed_blink(0.2, 1.0)
            text "." at delayed_blink(0.4, 1.0)


## This transform is used to blink the arrows one after another.
transform delayed_blink(delay, cycle):
    alpha .5

    pause delay

    block:
        linear .2 alpha 1.0
        pause .2
        linear .2 alpha 0.5
        pause (cycle - .4)
        repeat


style skip_frame is empty
style skip_text is gui_text
style skip_triangle is skip_text

style skip_frame:
    ypos gui.skip_ypos
    background Frame("gui/skip.png", gui.skip_frame_borders, tile=gui.frame_tile)
    padding gui.skip_frame_borders.padding

style skip_text:
    size gui.notify_text_size
    color "#fff"
    bold gui.navigation_button_text_bold


## Notify screen ###############################################################
##
## The notify screen is used to show the player a message. (For example, when
## the game is quicksaved or a screenshot has been taken.)
##
## https://www.renpy.org/doc/html/screen_special.html#notify-screen

##############################################################################

screen notify(message):

    zorder 100
    style_prefix "notify"

    add "gui/notify.png" yanchor -7 at notify_appear
    text "[message!tq]" at notify_appear

    timer 2 action Hide('notify')

transform notify_appear:
    on show:
        alpha 0 xpos -20
        linear .25 alpha 1.0 xpos 0
    on hide:
        linear .5 alpha 0.0 xpos -40

style notify_frame is empty
style notify_text is gui_text

style notify_frame:
    ypos gui.notify_ypos

    background Frame("gui/notify.png", gui.notify_frame_borders, tile=gui.frame_tile)
    padding gui.notify_frame_borders.padding

style notify_text:
    properties gui.text_properties("notify")
    color "#fff" outlines [(4, "#611437", 0, 0)] xanchor -56 yanchor gui.notify_yanchor


## NVL screen ##################################################################
##
## This screen is used for NVL-mode dialogue and menus.
##
## https://www.renpy.org/doc/html/screen_special.html#nvl


screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            ypos gui.nvl_startpos
            spacing gui.nvl_spacing

        ## Displays dialogue in either a vpgrid or the vbox.
        if gui.nvl_height:

            vpgrid:
                cols 1
                yinitial 1.0

                use nvl_dialogue(dialogue)

        else:

            use nvl_dialogue(dialogue)

        ## Displays the menu, if given. The menu may be displayed incorrectly if
        ## config.narrator_menu is set to True, as it is above.
        for i in items:

            textbutton i.caption:
                action i.action
                style "nvl_button"

    add SideImage() xalign 0.0 yalign 1.0


screen nvl_dialogue(dialogue):

    for d in dialogue:

        window:
            id d.window_id

            fixed:
                yfit gui.nvl_height is None

                if d.who is not None:

                    text d.who:
                        id d.who_id

                text d.what:
                    id d.what_id


## This controls the maximum number of NVL-mode entries that can be displayed at
## once.
define config.nvl_list_length = gui.nvl_list_length

style nvl_window is default
style nvl_entry is default

style nvl_label is say_label
style nvl_dialogue is say_dialogue

style nvl_button is button
style nvl_button_text is button_text

style nvl_window:
    xfill True
    yfill True

    background "gui/nvl.png"
    padding gui.nvl_borders.padding

style nvl_entry:
    xfill True
    ysize gui.nvl_height

style nvl_label:
    xpos gui.nvl_name_xpos
    xanchor gui.nvl_name_xalign
    ypos gui.nvl_name_ypos
    yanchor 0.0
    xsize gui.nvl_name_width
    min_width gui.nvl_name_width
    text_align gui.nvl_name_xalign

style nvl_dialogue:
    xpos gui.nvl_text_xpos
    xanchor gui.nvl_text_xalign
    ypos gui.nvl_text_ypos
    xsize gui.nvl_text_width
    min_width gui.nvl_text_width
    text_align gui.nvl_text_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_thought:
    xpos gui.nvl_thought_xpos
    xanchor gui.nvl_thought_xalign
    ypos gui.nvl_thought_ypos
    xsize gui.nvl_thought_width
    min_width gui.nvl_thought_width
    text_align gui.nvl_thought_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_button:
    properties gui.button_properties("nvl_button")
    xpos gui.nvl_button_xpos
    xanchor gui.nvl_button_xalign

style nvl_button_text:
    properties gui.button_text_properties("nvl_button")

screen language():

    tag menu

    use game_menu(_("Language"), scroll="viewport"):

        has vbox
        xminimum 840
        yminimum 420
        null height 10
        hbox:
            spacing 10
            frame:
                style "pref_frame"
                has vbox
                style_prefix "radio"
                xsize 300
                label _("Text Settings")
                textbutton "{font=tl/None/NomnomNami2.ttf}{size=36}English{/size}{/font}" action Language(None)
                textbutton "{font=tl/dys/OpenDyslexic-Regular.otf}{size=24}English (Dyslexic){/size}{/font}" action Language("dys")
            frame:
                style "pref_frame"
                has vbox
                style_prefix "radio"
                xsize 300
                label _("Language")
                grid 2 5:
                    textbutton "{font=tl/None/NomnomNami2.ttf}{size=36}Français{/size}{/font}" action Language("fr")
                    textbutton "{font=tl/kr/dovemayo_bold.otf}{size=36}한국어{/size}{/font}" action Language("kr")

                    textbutton "{font=tl/None/NomnomNami2.ttf}{size=36}Español{/size}{/font}" action Language("es")
                    textbutton "{font=tl/chinese/ZCOOLKuaiLe-Regular.ttf}{size=32}汉语{/size}{/font}" action Language("chinese")

                    textbutton "{font=tl/None/NomnomNami2.ttf}{size=36}Português{/size}{/font}" action Language("por")
                    textbutton "{font=tl/japanese/azuki.ttf}{size=36}日本語{/size}{/font}" action Language("japanese")

                    textbutton "{font=tl/None/NomnomNami2.ttf}{size=36}Deutsche{/size}{/font}" action Language("de")
                    textbutton "{font=tl/vi/PatrickHand-Regular.ttf}{size=36}Tiếng Việt{/size}{/font}" action Language("vi")

                    textbutton "{font=tl/None/NomnomNami2.ttf}{size=36}Polski{/size}{/font}" action Language("pl")
                    textbutton "{font=tl/thai/WR Tish Kid.ttf}{size=40}ภาษาไทย{/size}{/font}" action Language("thai")
    frame:
        style "pref_frame"
        align (.2,.72)
        textbutton _("Back") action ShowMenu("preferences")

screen endings():
    tag menu

    default unseenl = _("???")
    default unseen = _("*You haven't seen this ending yet.")

    use game_menu(_("Endings"), scroll="viewport"):
        style_prefix "ends"
        has vbox
        spacing 10
        frame:
            has vbox
            if persistent.syrupend:
                label _("Syrup End")
                text _("Syrup, disinterested in the people around her, put all her energy into capitalism. Now she's super rich.")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.gumdropend:
                label _("Gumdrop End")
                text _("Syrup and Gumdrop travel the world together to strengthen their bond <3")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.pastilleend:
                label _("Pastille End")
                text _("Syrup and Pastille go on adventures together to make LEGENDARY CANDIES!")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.butterscotchend:
                label _("Butterscotch End")
                text _("Syrup teaches Butterscotch how to make candy and it's oh so sweet.")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.toffeeend:
                label _("Toffee End")
                text _("Syrup adopts Toffee as her pet. Nya.")
            else:
                label unseenl
                text unseen

        frame:
            has vbox
            if persistent.candibalend:
                label _("Candibal End")
                text _("You ate her. I can't believe you actually ate her.")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.frozenend:
                label _("Frozen End")
                text _("Butterscotch couldn't melt the ice and no one came to save you.")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.badend1:
                label _("Bad End 1")
                text _("Syrup had to run the store by herself and failed horribly.")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.badend2:
                label _("Bad End 2")
                text _("Toffee and Butterscotch took over Atelier Sweets.")
            else:
                label unseenl
                text unseen
        frame:
            has vbox
            if persistent.worstend:
                label _("Worst End")
                text _("Syrup's heart completely froze over. How could you be so cruel?")
            else:
                label unseenl
                text unseen

style ends_label_text:
    color pasc
    outlines pasol
    size gui.interface_text_size
    bold gui.navigation_button_text_bold

style ends_text:
    color "#993c5f"
    outlines [(3, "#fff", 0, 0)]
    size gui.interface_text_size

style ends_frame is pref_frame:
    xsize 780

style ends_button_text:
    outlines [(3, "#c45f85", 0, 0)]

################################################################################
## Mobile Variants
################################################################################

screen preferences():
    variant "touch"

    tag menu

    use game_menu(_("Options"), scroll="viewport"):

        null height 10
        frame:
            style "pref_frame"
            has vbox
            style_prefix "check"
            spacing 0
            label _("Skip")
            hbox:
                xsize 788
                xfill True
                textbutton _("Unseen Text") action Preference("skip", "toggle")
                textbutton _("After Choices") action Preference("after choices", "toggle")
                textbutton _("Transitions") action InvertSelected(Preference("transitions", "toggle"))
        null height 10
        hbox:
            xsize 780
            frame:
                style "pref_frame"
                has vbox
                style_prefix "radio"
                spacing 0
                label _("Rollback Side")
                hbox:
                    xminimum gui.rollback_hbox_xminimum
                    textbutton _("Left") action Preference("rollback side", "left")
                    textbutton _("Right") action Preference("rollback side", "right")
                    textbutton _("Disable") action Preference("rollback side", "disable")
            null width 10
            frame:
                xalign .5 yalign .5
                style "pref_frame"
                has vbox
                null height 6
                textbutton _("Language...") action ShowMenu("language") activate_sound "audio/menubutton.wav"
        null height 10
        hbox:
            xsize 722
            spacing 10
            frame:
                style "pref_frame"
                style_prefix "slider"
                vbox:
                    # xminimum 360
                    label _("Text Speed")
                    bar value Preference("text speed")
                    label _("Auto-Forward Time")
                    bar value Preference("auto-forward time")
                    null height 10
            frame:
                style "pref_frame"
                xalign 1.0
                hbox:
                    vbox:
                        ysize 125
                        null height 4
                        hbox:
                            spacing 16
                            label _("Music:") style "slider_label"
                            textbutton _("ON") action Preference("music mute", "disable") yoffset 6
                            textbutton _("OFF") action Preference("music mute", "enable") yoffset 6
                        hbox:
                            spacing 16
                            label _("Sound:") style "slider_label"
                            textbutton _("ON") action Preference("sound mute", "disable") yoffset 6
                            textbutton _("OFF") action Preference("sound mute", "enable") yoffset 6
                    imagebutton auto "gui/button/mute_%s.png" action Preference("all mute", "toggle") yalign .5 activate_sound "audio/menubutton.wav"

style pref_vbox:
    variant "small"
    xsize None

# style slider_label_text:
#     variant "small"
#     size gui.button_text_size
style slider_vbox:
    variant "small"
    xsize gui.slider_vbox_xsize
style slider_pref_slider:
    variant "small"
    xsize 600

## Since a mouse may not be present, we replace the quick menu with a version
## that uses fewer and bigger buttons that are easier to touch.
screen quick_menu():
    variant "touch"

    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            textbutton _("Back") action Rollback()
            textbutton _("Skip") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Hide Textbox") action HideInterface() activate_sound None
            textbutton _("Menu") action ShowMenu()


style window:
    variant "small"
    background "gui/phone/textbox.png"

style radio_button:
    variant "small"
    foreground "gui/phone/button/radio_[prefix_]foreground.png"

style check_button:
    variant "small"
    foreground "gui/phone/button/check_[prefix_]foreground.png"

style nvl_window:
    variant "small"
    background "gui/phone/nvl.png"

style main_menu_frame:
    variant "small"
    background "gui/phone/overlay/main_menu.png"

style game_menu_navigation_frame:
    variant "small"
    xsize 340

style bar:
    variant "small"
    ysize gui.bar_size
    left_bar Frame("gui/phone/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/phone/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    variant "small"
    xsize gui.bar_size
    top_bar Frame("gui/phone/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/phone/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    variant "small"
    ysize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    variant "small"
    xsize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    variant "small"
    ysize gui.slider_size
    base_bar Frame("gui/phone/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/horizontal_[prefix_]thumb.png"

style vslider:
    variant "small"
    xsize gui.slider_size
    base_bar Frame("gui/phone/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/vertical_[prefix_]thumb.png"
